==> nextcloud-app-spreed-1%3A6.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/spreed/l10n/lt_LT.js <==
OC.L10N.register(
    "spreed",
    {
    "New conversation …" : "Naujas pokalbis …",
    "Participants" : "Dalyviai",
    "Exit fullscreen (f)" : "Išeiti iš viso ekrano (f)",
    "Fullscreen (f)" : "Visas ekranas (f)",
    "Copy" : "Kopijuoti",
    "Copied!" : "Nukopijuota!",
    "Not supported!" : "Nepalaikoma!",
    "Press ⌘-C to copy." : "Norėdami nukopijuoti, paspauskite ⌘-C.",
    "Error while getting the room ID" : "Klaida gaunant kambario ID",
    "Please enter the password for this call" : "Įveskite šio skambučio slaptažodį",
    "Password required" : "Reikalingas slaptažodis",
    "Password" : "Slaptažodis",
    "Cancel" : "Atsisakyti",
    "Submit" : "Pateikti",
    "Calls are disabled in this conversation." : "Šiame pokalbyje skambinti negalima.",
    "Share link" : "Dalinimosi nuoroda",
    "Change password" : "Pakeisti slaptažodį",
    "Set password" : "Nustatyti slaptažodį",
    "Go to file" : "Pereiti į failą",
    "Conversation name" : "Pokalbio pavadinimas",
    "Rename" : "Pervadinti",
    "Copy link" : "Kopijuoti nuorodą",
    "Conversation with {name}" : "Pokalbis su {name}",
    "Error occurred while setting password" : "Nustatant slaptažodį, atsirado klaidų",
    "Link copied!" : "Nuoroda nukopijuota!",
    "You" : "Jūs",
    "No messages yet, start the conversation!" : "Kol kas žinučių nėra, pradėkite pokalbį!",
    "New message …" : "Nauja žinutė …",
    "Send" : "Siųsti",
    "You can not send messages, because the conversation is locked." : "Negalite siųsti žinučių, nes pokalbis užrakintas.",
    "The conversation is locked." : "Pokalbis užrakintas.",
    "Guest" : "Svečias",
    "[Unknown user name]" : "[Nežinomas naudotojo vardas]",
    "Today" : "Šiandien",
    "Yesterday" : "Vakar",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "The message you are trying to send is too long" : "Žinutė, kurią bandote išsiųsti yra pernelyg ilga",
    "Error occurred while sending message" : "Siunčiant žinutę, įvyko klaida",
    "Say hi to your friends and colleagues!" : "Pasisveikinkite su savo draugais ir kolegomis!",
    "Waiting for {participantName} to join the call …" : "Laukiama kol {participantName} prisijungs prie skambučio …",
    "Waiting for others to join the call …" : "Laukiama kol kiti prisijungs prie skambučio …",
    "Share this link to invite others!" : "Bendrinkite šią nuorodą, norėdami pakviesti kitus!",
    "WebRTC is not supported in your browser :-/" : "Jūsų naršyklėje WebRTC nėra palaikoma :-/",
    "Please use a different browser like Firefox or Chrome" : "Naudokite kitą naršyklę, tokią kaip Firefox ar Chrome",
    "Waiting for camera and microphone permissions" : "Laukiama kameros ir mikrofono leidimų",
    "Please, give your browser access to use your camera and microphone in order to use this app." : "Norėdami naudoti šią programėlę, suteikite savo naršyklei prieigą naudoti jūsų kamerą ir mikrofoną.",
    "Mute audio" : "Nutildyti garsą",
    "Disable video" : "Išjungti vaizdą",
    "Show your screen" : "Rodyti savo ekraną",
    "Stop screensharing" : "Stabdyti ekrano bendrinimą",
    "Mute audio (m)" : "Nutildyti garsą (m)",
    "Unmute audio (m)" : "Įjungti garsą (m)",
    "Disable video (v)" : "Išjungti vaizdą (v)",
    "Enable video (v)" : "Įjungti vaizdą (v)",
    "Screensharing is not supported by your browser." : "Jūsų naršyklė nepalaiko ekrano bendrinimo.",
    "Screensharing requires the page to be loaded through HTTPS." : "Ekrano bendrinimas reikalauja, kad puslapis būtų įkeltas per HTTPS.",
    "Screensharing options" : "Ekrano bendrinimo parinktys",
    "Sharing your screen only works with Firefox version 52 or newer." : "Ekrano bendrinimas veikia tik naudojant Firefox 52 arba naujesnę versiją.",
    "Screensharing extension is required to share your screen." : "Norint bendrinti ekraną yra reikalingas ekrano bendrinimo plėtinys.",
    "Please use a different browser like Firefox or Chrome to share your screen." : "Norėdami bendrinti savo ekraną, naudokite kitą naršyklę, tokią kaip Firefox ar Chrome.",
    "An error occurred while starting screensharing." : "Pradedant ekrano bendrinimą, įvyko klaida.",
    "Enable screensharing" : "Įjungti ekrano bendrinimą",
    "moderator" : "moderatorius",
    "Remove participant" : "Šalinti dalyvį",
    "Add participant …" : "Pridėti dalyvį …",
    "Favorited" : "Pažymėtas svarbiu",
    "Remove from favorites" : "Šalinti iš mėgstamų",
    "Add to favorites" : "Pridėti į mėgstamus",
    "Always notify" : "Visada pranešti",
    "Never notify" : "Niekada nepranešti",
    "Delete conversation" : "Ištrinti pokalbį",
    "Your screen" : "Jūsų ekranas",
    "Guest's screen" : "Svečio ekranas",
    "Close" : "Užverti",
    "Show screen" : "Rodyti ekraną",
    "Enable video" : "Įjungti vaizdą",
    "Access to microphone & camera is only possible with HTTPS" : "Prieiga prie mikrofono ir kameros yra įmanoma tik naudojant HTTPS",
    "Please move your setup to HTTPS" : "Perkelkite savo sąranką į HTTPS",
    "Access to microphone & camera was denied" : "Prieiga prie mikrofono ir kameros buvo atmesta",
    "WebRTC is not supported in your browser" : "Jūsų naršyklėje WebRTC nėra palaikoma",
    "Error while accessing microphone & camera" : "Klaida, gaunant prieigą prie mikrofono ir kameros",
    "(Duration %s)" : "(Trukmė %s)",
    "_%n guest_::_%n guests_" : ["%n svečias","%n svečiai","%n svečių","%n svečių"],
    "{actor} invited you to {call}" : "{actor} pakvietė jus į {call}",
    "{actor} unlocked the conversation" : "{actor} atrakino pokalbį",
    "You unlocked the conversation" : "Atblokavote pokalbį",
    "{actor} locked the conversation" : "{actor} užrakino pokalbį",
    "You locked the conversation" : "Jūs užrakinote pokalbį",
    "{actor} set a password" : "{actor} nustatė slaptažodį",
    "You set a password" : "Jūs nustatėte slaptažodį",
    "{actor} removed the password" : "{actor} pašalino slaptažodį",
    "You removed the password" : "Jūs pašalinote slaptažodį",
    "{actor} added {user}" : "{actor} pridėjo naudotoją {user}",
    "You added {user}" : "Jūs pridėjote naudotoją {user}",
    "{actor} added you" : "{actor} jus pridėjo",
    "{actor} removed {user}" : "{actor} pašalino naudotoją {user}",
    "You removed {user}" : "Jūs pašalinote naudotoją {user}",
    "{actor} removed you" : "{actor} jus pašalino",
    "%s (guest)" : "%s (svečias)",
    "%s invited you to a conversation." : "%s jus pakvietė į pokalbį.",
    "You were invited to a conversation." : "Jūs buvote pakviesti į pokalbį.",
    "{user} mentioned you in a private conversation" : "{user} jus paminėjo privačiame pokalbyje",
    "%s invited you to a private conversation" : "%s jus pakvietė į privatų pokalbį",
    "{user} invited you to a private conversation" : "{user} jus pakvietė į privatų pokalbį",
    "%s invited you to a group conversation: %s" : "%s jus pakvietė į grupės pokalbį: %s",
    "{user} invited you to a group conversation: {call}" : "{user} jus pakvietė į grupės pokalbį: {call}",
    "{user} wants to talk with you" : "{user} nori su jumis pasikalbėti",
    "Conversation not found" : "Pokalbis nerastas",
    "TURN server URL" : "TURN serverio URL",
    "STUN server URL" : "STUN serverio URL",
    "TURN server protocols" : "TURN serverio protokolai",
    "UDP and TCP" : "UDP ir TCP",
    "UDP only" : "Tik UDP",
    "TCP only" : "Tik TCP",
    "Saved" : "Įrašyta",
    "STUN servers" : "STUN serveriai",
    "This call is password-protected" : "Šis skambutis yra apsaugotas slaptažodžiu",
    "The password is wrong. Try again." : "Slaptažodis neteisingas. Bandykite dar kartą.",
    "TURN server" : "TURN serveris",
    "Android app" : "Android programėlė",
    "iOS app" : "iOS programėlė",
    "Delete server" : "Ištrinti serverį",
    "Add new server" : "Pridėti naują serverį",
    "New public conversation" : "Naujas viešas pokalbis",
    "New group conversation" : "Naujas grupės pokalbis",
    "_%n other guest_::_%n other guests_" : ["ir dar %n svečias","ir dar %n svečiai","ir dar %n svečių","ir dar %n svečias"],
    ", " : ", ",
    "%s mentioned you in a private conversation" : "%s jus paminėjo privačiame pokalbyje",
    "%s mentioned you in a group conversation: %s" : "%s jus paminėjo grupės pokalbyje: %s",
    "{user} mentioned you in a group conversation: {call}" : "{user} jus paminėjo grupės pokalbyje: {call}",
    "%s mentioned you in a group conversation" : "%s jus paminėjo grupės pokalbyje",
    "{user} mentioned you in a group conversation" : "{user} jus paminėjo grupės pokalbyje",
    "You were mentioned in a group conversation by a deleted user: %s" : "Ištrintas naudotojas jus paminėjo grupės pokalbyje: %s",
    "You were mentioned in a group conversation by a deleted user: {call}" : "Ištrintas naudotojas jus paminėjo grupės pokalbyje: {call}",
    "You were mentioned in a group conversation by a deleted user" : "Ištrintas naudotojas jus paminėjo grupės pokalbyje",
    "A guest mentioned you in a group conversation: %s" : "Svečias jus paminėjo grupės pokalbyje: %s",
    "A guest mentioned you in a group conversation: {call}" : "Svečias jus paminėjo grupės pokalbyje: {call}",
    "A guest mentioned you in a group conversation" : "Svečias jus paminėjo grupės pokalbyje",
    "%s invited you to a group conversation" : "%s jus pakvietė į grupės pokalbį",
    "{user} invited you to a group conversation" : "{user} jus pakvietė į grupės pokalbį"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-app-spreed-1%3A6.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/spreed/l10n/lt_LT.js <==
OC.L10N.register(
    "spreed",
    {
    "New conversation …" : "Naujas pokalbis …",
    "Participants" : "Dalyviai",
    "Exit fullscreen (f)" : "Išeiti iš viso ekrano (f)",
    "Fullscreen (f)" : "Visas ekranas (f)",
    "Copy" : "Kopijuoti",
    "Copied!" : "Nukopijuota!",
    "Not supported!" : "Nepalaikoma!",
    "Press ⌘-C to copy." : "Norėdami nukopijuoti, paspauskite ⌘-C.",
    "Error while getting the room ID" : "Klaida gaunant kambario ID",
    "Request password" : "Užklausti slaptažodį",
    "Error requesting the password." : "Klaida užklausiant slaptažodį.",
    "Please enter the password for this call" : "Įveskite šio skambučio slaptažodį",
    "Password required" : "Reikalingas slaptažodis",
    "Password" : "Slaptažodis",
    "Cancel" : "Atsisakyti",
    "Submit" : "Pateikti",
    "Calls are disabled in this conversation." : "Šiame pokalbyje skambinti negalima.",
    "Go to file" : "Pereiti į failą",
    "Share link" : "Dalinimosi nuoroda",
    "Change password" : "Pakeisti slaptažodį",
    "Set password" : "Nustatyti slaptažodį",
    "Conversation name" : "Pokalbio pavadinimas",
    "Rename" : "Pervadinti",
    "Copy link" : "Kopijuoti nuorodą",
    "Conversation with {name}" : "Pokalbis su {name}",
    "Error occurred while setting password" : "Nustatant slaptažodį, atsirado klaidų",
    "Link copied!" : "Nuoroda nukopijuota!",
    "You" : "Jūs",
    "No messages yet, start the conversation!" : "Kol kas žinučių nėra, pradėkite pokalbį!",
    "New message …" : "Nauja žinutė …",
    "Send" : "Siųsti",
    "You can not send messages, because the conversation is locked." : "Negalite siųsti žinučių, nes pokalbis užrakintas.",
    "The conversation is locked." : "Pokalbis užrakintas.",
    "Guest" : "Svečias",
    "[Unknown user name]" : "[Nežinomas naudotojo vardas]",
    "Today" : "Šiandien",
    "Yesterday" : "Vakar",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "The message you are trying to send is too long" : "Žinutė, kurią bandote išsiųsti yra pernelyg ilga",
    "Error occurred while sending message" : "Siunčiant žinutę, įvyko klaida",
    "Error while sharing" : "Klaida bendrinant",
    "Edit" : "Taisyti",
    "Say hi to your friends and colleagues!" : "Pasisveikinkite su savo draugais ir kolegomis!",
    "Waiting for {participantName} to join the call …" : "Laukiama kol {participantName} prisijungs prie skambučio …",
    "Waiting for others to join the call …" : "Laukiama kol kiti prisijungs prie skambučio …",
    "Share this link to invite others!" : "Bendrinkite šią nuorodą, norėdami pakviesti kitus!",
    "WebRTC is not supported in your browser :-/" : "Jūsų naršyklėje WebRTC nėra palaikoma :-/",
    "Please use a different browser like Firefox or Chrome" : "Naudokite kitą naršyklę, tokią kaip Firefox ar Chrome",
    "Waiting for camera and microphone permissions" : "Laukiama kameros ir mikrofono leidimų",
    "Please, give your browser access to use your camera and microphone in order to use this app." : "Norėdami naudoti šią programėlę, suteikite savo naršyklei prieigą naudoti jūsų kamerą ir mikrofoną.",
    "Mute audio" : "Nutildyti garsą",
    "Disable video" : "Išjungti vaizdą",
    "Show your screen" : "Rodyti savo ekraną",
    "Stop screensharing" : "Stabdyti ekrano bendrinimą",
    "Mute audio (m)" : "Nutildyti garsą (m)",
    "Unmute audio (m)" : "Įjungti garsą (m)",
    "Disable video (v)" : "Išjungti vaizdą (v)",
    "Enable video (v)" : "Įjungti vaizdą (v)",
    "Screensharing is not supported by your browser." : "Jūsų naršyklė nepalaiko ekrano bendrinimo.",
    "Screensharing requires the page to be loaded through HTTPS." : "Ekrano bendrinimas reikalauja, kad puslapis būtų įkeltas per HTTPS.",
    "Screensharing options" : "Ekrano bendrinimo parinktys",
    "Sharing your screen only works with Firefox version 52 or newer." : "Ekrano bendrinimas veikia tik naudojant Firefox 52 arba naujesnę versiją.",
    "Screensharing extension is required to share your screen." : "Norint bendrinti ekraną yra reikalingas ekrano bendrinimo plėtinys.",
    "Please use a different browser like Firefox or Chrome to share your screen." : "Norėdami bendrinti savo ekraną, naudokite kitą naršyklę, tokią kaip Firefox ar Chrome.",
    "An error occurred while starting screensharing." : "Pradedant ekrano bendrinimą, įvyko klaida.",
    "Enable screensharing" : "Įjungti ekrano bendrinimą",
    "moderator" : "moderatorius",
    "Remove participant" : "Šalinti dalyvį",
    "Add participant …" : "Pridėti dalyvį …",
    "Favorited" : "Pažymėtas svarbiu",
    "Remove from favorites" : "Šalinti iš mėgstamų",
    "Add to favorites" : "Pridėti į mėgstamus",
    "Always notify" : "Visada pranešti",
    "Never notify" : "Niekada nepranešti",
    "Delete conversation" : "Ištrinti pokalbį",
    "Your screen" : "Jūsų ekranas",
    "Guest's screen" : "Svečio ekranas",
    "Close" : "Užverti",
    "Show screen" : "Rodyti ekraną",
    "Enable video" : "Įjungti vaizdą",
    "Access to microphone & camera is only possible with HTTPS" : "Prieiga prie mikrofono ir kameros yra įmanoma tik naudojant HTTPS",
    "Please move your setup to HTTPS" : "Perkelkite savo sąranką į HTTPS",
    "Access to microphone & camera was denied" : "Prieiga prie mikrofono ir kameros buvo atmesta",
    "WebRTC is not supported in your browser" : "Jūsų naršyklėje WebRTC nėra palaikoma",
    "Error while accessing microphone & camera" : "Klaida, gaunant prieigą prie mikrofono ir kameros",
    "(Duration %s)" : "(Trukmė %s)",
    "_%n guest_::_%n guests_" : ["%n svečias","%n svečiai","%n svečių","%n svečių"],
    "{actor} invited you to {call}" : "{actor} pakvietė jus į {call}",
    "There are currently no commands available." : "Šiuo metu nėra prieinamų komandų.",
    "The command does not exist" : "Komandos nėra",
    "{actor} created the conversation" : "{actor} sukūrė pokalbį",
    "You created the conversation" : "Jūs sukūrėte pokalbį",
    "{actor} unlocked the conversation" : "{actor} atrakino pokalbį",
    "You unlocked the conversation" : "Atblokavote pokalbį",
    "{actor} locked the conversation" : "{actor} užrakino pokalbį",
    "You locked the conversation" : "Jūs užrakinote pokalbį",
    "{actor} set a password" : "{actor} nustatė slaptažodį",
    "You set a password" : "Jūs nustatėte slaptažodį",
    "{actor} removed the password" : "{actor} pašalino slaptažodį",
    "You removed the password" : "Jūs pašalinote slaptažodį",
    "{actor} added {user}" : "{actor} pridėjo naudotoją {user}",
    "You added {user}" : "Jūs pridėjote naudotoją {user}",
    "{actor} added you" : "{actor} jus pridėjo",
    "{actor} removed {user}" : "{actor} pašalino naudotoją {user}",
    "You removed {user}" : "Jūs pašalinote naudotoją {user}",
    "{actor} removed you" : "{actor} jus pašalino",
    "%s (guest)" : "%s (svečias)",
    "File is not shared, or shared but not with the user" : "Failas nėra bendrinamas arba yra bendrinamas, tačiau ne su naudotoju",
    "%s invited you to a conversation." : "%s jus pakvietė į pokalbį.",
    "You were invited to a conversation." : "Jūs buvote pakviesti į pokalbį.",
    "Click the button below to join." : "Norėdami prisijungti, spustelėkite mygtuką žemiau.",
    "Join »%s«" : "Prisijungti prie »%s«",
    "{user} mentioned you in a private conversation" : "{user} jus paminėjo privačiame pokalbyje",
    "%s invited you to a private conversation" : "%s jus pakvietė į privatų pokalbį",
    "{user} invited you to a private conversation" : "{user} jus pakvietė į privatų pokalbį",
    "%s invited you to a group conversation: %s" : "%s jus pakvietė į grupės pokalbį: %s",
    "{user} invited you to a group conversation: {call}" : "{user} jus pakvietė į grupės pokalbį: {call}",
    "{user} wants to talk with you" : "{user} nori su jumis pasikalbėti",
    "Someone requested the password to access {file}" : "Kažkas užklausė slaptažodį, kad gautų prieigą prie {file}",
    "Conversation not found" : "Pokalbis nerastas",
    "TURN server URL" : "TURN serverio URL",
    "Delete this server" : "Ištrinti šį serverį",
    "STUN server URL" : "STUN serverio URL",
    "TURN server protocols" : "TURN serverio protokolai",
    "UDP and TCP" : "UDP ir TCP",
    "UDP only" : "Tik UDP",
    "TCP only" : "Tik TCP",
    "Test this server" : "Išbandyti šį serverį",
    "Save changes" : "Įrašyti pakeitimus",
    "Saving …" : "Įrašoma …",
    "Saved!" : "Įrašyta!",
    "Commands" : "Komandos",
    "Command" : "Komanda",
    "Script" : "Scenarijus",
    "Saved" : "Įrašyta",
    "Add a new server" : "Pridėti naują serverį",
    "STUN servers" : "STUN serveriai",
    "TURN servers" : "TURN serveriai",
    "The password is wrong. Try again." : "Slaptažodis neteisingas. Bandykite dar kartą.",
    "TURN server" : "TURN serveris",
    "Android app" : "Android programėlė",
    "iOS app" : "iOS programėlė",
    "Delete server" : "Ištrinti serverį",
    "Add new server" : "Pridėti naują serverį",
    "Test server" : "Išbandyti serverį",
    "New public conversation" : "Naujas viešas pokalbis",
    "New group conversation" : "Naujas grupės pokalbis",
    "_%n other guest_::_%n other guests_" : ["ir dar %n svečias","ir dar %n svečiai","ir dar %n svečių","ir dar %n svečias"],
    ", " : ", ",
    "%s mentioned you in a private conversation" : "%s jus paminėjo privačiame pokalbyje",
    "%s mentioned you in a group conversation: %s" : "%s jus paminėjo grupės pokalbyje: %s",
    "{user} mentioned you in a group conversation: {call}" : "{user} jus paminėjo grupės pokalbyje: {call}",
    "%s mentioned you in a group conversation" : "%s jus paminėjo grupės pokalbyje",
    "{user} mentioned you in a group conversation" : "{user} jus paminėjo grupės pokalbyje",
    "You were mentioned in a group conversation by a deleted user: %s" : "Ištrintas naudotojas jus paminėjo grupės pokalbyje: %s",
    "You were mentioned in a group conversation by a deleted user: {call}" : "Ištrintas naudotojas jus paminėjo grupės pokalbyje: {call}",
    "You were mentioned in a group conversation by a deleted user" : "Ištrintas naudotojas jus paminėjo grupės pokalbyje",
    "A guest mentioned you in a group conversation: %s" : "Svečias jus paminėjo grupės pokalbyje: %s",
    "A guest mentioned you in a group conversation: {call}" : "Svečias jus paminėjo grupės pokalbyje: {call}",
    "A guest mentioned you in a group conversation" : "Svečias jus paminėjo grupės pokalbyje",
    "%s invited you to a group conversation" : "%s jus pakvietė į grupės pokalbį",
    "{user} invited you to a group conversation" : "{user} jus pakvietė į grupės pokalbį",
    "Unnamed conversation" : "Pokalbis be pavadinimo",
    "This call is password-protected" : "Šis skambutis yra apsaugotas slaptažodžiu"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
